Package {BsplineQuantRegGui}


Type: Package
Title: Interactive 'Shiny' Interface for 'BsplineQuantReg'
Version: 0.2.2
Language: en-GB
Date: 2026-07-28
Description: A user-friendly interactive Shiny interface for the 'BsplineQuantReg' package, enabling quantile regression using B-splines with shape constraints, based on the method described in Abbes (2025). Almost all parameters of the main function 'quantile_spline()' can be tuned. Features include interactive knot placement, per-region constraint specification, 'CSV' data import, direct demo access, reproducible R code generation, and solver selection. The version 0.2.2 handles knots multiplicity, Bspline basis visualisation, mean-square regression, pp form visualisation under human readable form, in local or canonical bases, The GUI provides two modes, basic (compatible with 'BsplineQuantReg' >= 0.2.2) and advanced (requires 'BsplineQuantReg' >= 0.2.5 for stable multiplicity features). This GUI an improved version of the 'Python Tk' version of 'BsplineQuantRegPy'.
License: GPL-3
Encoding: UTF-8
Depends: R (≥ 4.6.0)
Imports: BsplineQuantReg (≥ 0.2.5), shiny, shinyjs, DT, plotly, png, shinythemes, colourpicker, png, ECOSolveR
Suggests: cobs, testthat
Config/testthat/edition: 3
NeedsCompilation: no
Config/roxygen2/version: 8.1.0
Packaged: 2026-08-21 20:18:23 UTC; abbes
Author: Alexandre Abbes [aut, cre]
Maintainer: Alexandre Abbes <alexandre.abbes@proton.me>
Repository: CRAN
Date/Publication: 2026-09-01 08:50:15 UTC

Launch 'BsplineQuantReg' Shiny Interface (Wrapper Function)

Description

Unified launcher for both basic and advanced versions of the application.

Usage

run_gui(
  level = "advanced",
  brow = TRUE,
  rstudio = FALSE,
  host = "127.0.0.1",
  port = 3674
)

Arguments

level

Character or numeric. Specify which version to launch: 1 or "basic": Basic version 2 or "advanced": Advanced version (default)

brow

Logical. If TRUE, launches the app in the system's default browser.

rstudio

Logical. If TRUE, launches the app in RStudio's viewer pane.

host

Character. Server address. Default is '127.0.0.1'.

port

Integer. Port to run the app on. Default is 3674.

Value

Launches the selected Shiny application.

Examples

## Not run: 
# Launch advanced version (default)
run_gui()
run_gui("advanced")
run_gui(2)

# Launch basic version
run_gui("basic")
run_gui(1)

## End(Not run)


Launch the 'BsplineQuantReg' Shiny Interface - Basic Version

Description

Opens an interactive Shiny application for quantile regression using B-splines with shape constraints. This is the basic version with standard features.

Usage

run_gui1(brow = TRUE, rstudio = FALSE, host = "127.0.0.1", port = 3674)

Arguments

brow

Logical. If TRUE, launches the app in the system's default browser.

rstudio

Logical. If TRUE, launches the app in RStudio's viewer pane. If FALSE, uses the system default.

host

Character. Server address. Default is '127.0.0.1'.

port

Integer. Port to run the app on. Default is 3674.

Details

Features:

Not included:

Version Compatibility:

Value

Launches a Shiny application. The function returns invisibly when the app stops.

See Also

run_gui2 for the advanced version

Examples

## Not run: 
# Launch basic version
run_gui1()

## End(Not run)


Launch the 'BsplineQuantReg' Shiny Interface - Advanced Version

Description

Opens an interactive Shiny application for quantile regression using B-splines with shape constraints. This version includes advanced features such as:

Usage

run_gui2(brow = TRUE, rstudio = FALSE, host = "127.0.0.1", port = 3674)

Arguments

brow

Logical. If TRUE, launches the app in the system's default browser.

rstudio

Logical. If TRUE, launches the app in RStudio's viewer pane. If FALSE, uses the system default.

host

Character. Server address. Default is '127.0.0.1'.

port

Integer. Port to run the app on. Default is 3674.

Details

Version Compatibility:

Value

Launches a Shiny application. The function returns invisibly when the app stops.

See Also

run_gui1 for the basic version

Examples

## Not run: 
# Launch in default browser
run_gui2()

# Launch in RStudio viewer
run_gui2(rstudio = TRUE)

# Launch on custom port
run_gui2(port = 8080)

## End(Not run)